.. highlight:: shell

============
Installation
============

For FMU users
-------------

**A normal user will not need to install anything!**

The stable and bleeding release of the scripts is distributed
within Equinor through Komodo. The front-end to run is the ``fmuconfig`` script:

.. code-block:: console

    $ fmuconfig the_master_file.yml <options...>


For developers
--------------

See the Contributing documentation.
